@@ -568,8 +568,11 @@ int main(int argc, char *argv[])
 					sc = strdup(dummy + 1);
 
 					/* lines are normally terminated with a
-					 * LF
+					 * CR/LF
 					 */
+					dummy = strchr(sc, '\r');
+					if (dummy)
+						*dummy = 0x00;
 					dummy = strchr(sc, '\n');
 					if (dummy)
 						*dummy = 0x00;
@@ -656,6 +659,8 @@ int main(int argc, char *argv[])
 					snprintf(last_error, ERROR_BUFFER_SIZE, "error shutting down ssl\n");
 					emit_error();
 				}
+
+				SSL_free(ssl_h);
 			}
 #endif
 			close(fd);
