@@ -18,6 +18,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netinet/tcp.h>
+#include <arpa/inet.h>
 #include <netdb.h>
 #include <errno.h>
 #include <stdio.h>
@@ -30,7 +31,7 @@
 
 extern char last_error[];
 
-int connect_to(struct sockaddr_in *addr, int portnr, int timeout)
+int connect_to(struct sockaddr *bind_to, struct sockaddr_in *addr, int portnr, int timeout)
 {
 	int     fd;
 	int 	rc;
@@ -45,6 +46,16 @@ int connect_to(struct sockaddr_in *addr, int portnr, int timeout)
 		return -1;
 	}
 
+	/* go through a specific interface? */
+	if (bind_to)
+	{
+		if (bind(fd, bind_to, sizeof(*bind_to)) == -1)
+		{
+			snprintf(last_error, ERROR_BUFFER_SIZE, "error binding to interface (%s)", strerror(errno));
+			return -1;
+		}
+	}
+
 	/* initialize address structure */
 	addr -> sin_port   = htons(portnr);
 
