@@ -13,5 +13,7 @@
   files in the program, then also delete it here.
 */
 
-void * mymalloc(int size, char *what);
-void * myrealloc(void *oldp, int newsize, char *what);
+double get_ts(void);
+
+#define min(x, y)	((x) < (y) ? (x) : (y))
+#define max(x, y)	((x) > (y) ? (x) : (y))
